@@ -2,20 +2,22 @@
 # SPDX-License-Identifier: MIT
 """MBS handler functions."""
 
+from __future__ import absolute_import
 import logging
+
 import kobo.rpmlib
 
-from module_build_service import conf
-from module_build_service import models
-from module_build_service.errors import UnprocessableEntity
-from module_build_service.resolver.base import GenericResolver
-from module_build_service.utils.general import import_mmd, load_mmd
-from module_build_service.utils.request_utils import requests_session
+from module_build_service.common import models
+from module_build_service.common.config import conf
+from module_build_service.common.errors import UnprocessableEntity
+from module_build_service.common.request_utils import requests_session
+from module_build_service.common.utils import load_mmd, import_mmd
+from module_build_service.resolver.KojiResolver import KojiResolver
 
 log = logging.getLogger()
 
 
-class MBSResolver(GenericResolver):
+class MBSResolver(KojiResolver):
 
     backend = "mbs"
 
@@ -208,7 +210,7 @@ class MBSResolver(GenericResolver):
         return mmds
 
     def get_compatible_base_module_modulemds(
-        self, name, stream, stream_version_lte, virtual_streams, states
+        self, base_module_mmd, stream_version_lte, virtual_streams, states
     ):
         """
         Returns the Modulemd metadata of base modules compatible with base module
@@ -219,8 +221,7 @@ class MBSResolver(GenericResolver):
         If `virtual_streams` are defined, the compatibility is also extended to
         all base module streams which share the same virtual stream.
 
-        :param name: Name of the base module.
-        :param stream: Stream of the base module.
+        :param base_module_mmd: Modulemd medatada defining the input base module.
         :param stream_version_lte: If True, the compatible streams are limited
              by the stream version computed from `stream`. If False, even the
              modules with higher stream version are returned.
@@ -229,12 +230,15 @@ class MBSResolver(GenericResolver):
             one of the virtual streams.
         :param states: List of states the returned compatible modules should
             be in.
+        :return list: List of Modulemd objects.
         """
+        name = base_module_mmd.get_module_name()
+        stream = base_module_mmd.get_stream_name()
         return self.get_module_modulemds(
             name, stream, stream_version_lte=stream_version_lte, virtual_streams=virtual_streams,
             states=states)
 
-    def get_buildrequired_modulemds(self, name, stream, base_module_nsvc):
+    def get_buildrequired_modulemds(self, name, stream, base_module_mmd):
         """
         Returns modulemd metadata of all module builds with `name` and `stream` buildrequiring
         base module defined by `base_module_nsvc` NSVC.
@@ -252,8 +256,21 @@ class MBSResolver(GenericResolver):
         if local_modules:
             return [m.mmd() for m in local_modules]
 
-        modules = self._get_modules(name, stream, strict=False, base_module_br=base_module_nsvc)
-        return [load_mmd(module["modulemd"]) for module in modules]
+        tag = base_module_mmd.get_xmd().get("mbs", {}).get("koji_tag_with_modules")
+        if tag:
+            # In case KojiResolver is enabled for this base module, ask Koji for list of
+            # Koji builds and then get the modulemd file from the MBS running in infra.
+            koji_builds = self.get_buildrequired_koji_builds(name, stream, base_module_mmd)
+            ret = []
+            for build in koji_builds:
+                version, context = build["release"].split(".")
+                ret += self.get_module_modulemds(name, stream, version, context, strict=True)
+
+            return ret
+        else:
+            modules = self._get_modules(
+                name, stream, strict=False, base_module_br=base_module_mmd.get_nsvc())
+            return [load_mmd(module["modulemd"]) for module in modules]
 
     def resolve_profiles(self, mmd, keys):
         """
@@ -264,7 +281,7 @@ class MBSResolver(GenericResolver):
                  set to union of all components defined in all installation
                  profiles matching the key using the buildrequires.
 
-        If there are some modules loaded by utils.load_local_builds(...), these
+        If there are some modules loaded by load_local_builds(...), these
         local modules will be considered when returning the profiles.
 
         https://pagure.io/fm-orchestrator/issue/181
@@ -391,7 +408,7 @@ class MBSResolver(GenericResolver):
         Resolves the requires list of N:S or N:S:V:C to a dictionary with keys as
         the module name and the values as a dictionary with keys of ref,
         stream, version.
-        If there are some modules loaded by utils.load_local_builds(...), these
+        If there are some modules loaded by load_local_builds(...), these
         local modules will be considered when resolving the requires. A RuntimeError
         is raised on MBS lookup errors.
         :param requires: a list of N:S or N:S:V:C strings
@@ -410,7 +427,7 @@ class MBSResolver(GenericResolver):
                 raise ValueError(
                     "Only N:S or N:S:V:C is accepted by resolve_requires, got %s" % nsvc)
             # Try to find out module dependency in the local module builds
-            # added by utils.load_local_builds(...).
+            # added by load_local_builds(...).
             local_modules = models.ModuleBuild.local_modules(
                 self.db_session, module_name, module_stream)
             if local_modules:
